==> robotour_3.1.0.orig.tar.gz: robotour-3.1.0/robotour/robglob.h <==
#ifndef __RT_GLOBALS__
#define __RT_GLOBALS__

#include <rtsystem.h>
#include <rtmath.h>
#include <rtini.h>

//using namespace lrt;

// You must not include anything else from RoboTour in this file.
#include "robvars.h"


namespace rt {
// fwd declaration
class ErrorHandler;

/*****************************************************************************/
/* The global variables for the game - also known as the OptionSet (RCO)     */
/*****************************************************************************/

class Globals{
public:
	rint fields;
	rint fieldsX;
	rint fieldsY;
	rint enableElim;
	rint elim;
	unsigned long timeout;
	rint maxCreateDur;
	rint maxSleepDur;
	rint maxInstrDur;
	rint maxGeneration;
	rint enableRC3Instr;
	rint enableMultitasking;
	rint enableFAT;
	rint enableLifetime;
	rint enableNutcracker; 
	rint firstRobotMobile;
	rint minId;
	rint maxId;

	rint maxInstr;
	rint maxBanks;
	rint maxVars;
	rint maxTasks;//
	rint maxMybots;//
	unsigned long maxLifetime;//

	rint durDie;
	rint durMove;
	rint durTurn;
	rint durAjump;//
	rint durJump;
	rint durBjump;
	rint durScan;
	rint durFarscan;//
	rint durFarscanPerField;//
	rint durSet;
	rint durAdd;
	rint durSub;
	rint durMul;//
	rint durDiv;//
	rint durMod;//
	rint durMin;//
	rint durMax;//
	rint durTrans;
	rint durTransPerInstr;
	rint durRtrans;//
	rint durRtransPerInstr;//
	rint durComp;
	rint durNcomp;//
	rint durGcomp;//
	rint durLcomp;//
	rint durRandom;//
	rint durCreate;
	rint durCreatePerBank;
	rint durCreateMulMobile;
	rint durCreateAddMobile;//
	rint durCreateAdvISet;
	rint durCreateSuperISet;

	rint durBreak;//
	rint durInit;//
	rint durSeize;//
	rint durResume;//
	rint durQuit;//

	rint durRemote;

	/// Read the global variables (the option set) from a RCO file.
	bool getGlobals(const lrt::String& filename);

	/// Creates a new Globals object. Errors will be reported using the given ErrorHandler.
	Globals(const ErrorHandler* errHandler) : errHandler(errHandler) {}
	~Globals() {}

private:
	const ErrorHandler* errHandler;

	// Fetches a rint from an ini file section
	rint getRint( lrt::IniSection& sec, const char* name, rint def = -1, rint min = MIN_RINT, rint max = MAX_RINT);

	// Fetches an int from an ini file section
	int getInt( lrt::IniSection& sec, const char* name, int def = -1, int min = lrt::Math::MIN_INT, int max = lrt::Math::MAX_INT);
};



} // namespace

#endif

==> robotour_3.1.1.orig.tar.gz: robotour-3.1.0/robotour/robglob.h <==
/*
 * robglob.h
 * 
 * Copyright (c) 2000-2004 by Florian Fischer (florianfischer@gmx.de)
 * and Martin Trautmann (martintrautmann@gmx.de) 
 * 
 * This file may be distributed and/or modified under the terms of the 
 * GNU General Public License version 2 as published by the Free Software 
 * Foundation. 
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

/** @file
  * Declares the Globals class (RCO stuff)
  */

#ifndef __RT_GLOBALS__
#define __RT_GLOBALS__

#include <rtsystem.h>
#include <rtmath.h>
#include <rtini.h>

//using namespace lrt;

// You must not include anything else from RoboTour in this file.
#include "robvars.h"


namespace rt {
// fwd declaration
class ErrorHandler;

/// The global variables for the game - also known as the OptionSet (RCO)     */
class Globals{
public:
	rint fields;
	rint fieldsX;
	rint fieldsY;
	rint enableElim;
	rint elim;
	unsigned long timeout;
	rint maxCreateDur;
	rint maxSleepDur;
	rint maxInstrDur;
	rint maxGeneration;
	rint enableRC3Instr;
	rint enableMultitasking;
	rint enableFAT;
	rint enableLifetime;
	rint enableNutcracker; 
	rint firstRobotMobile;
	rint minId;
	rint maxId;

	rint maxInstr;
	rint maxBanks;
	rint maxVars;
	rint maxTasks;//
	rint maxMybots;//
	unsigned long maxLifetime;//

	rint durDie;
	rint durMove;
	rint durTurn;
	rint durAjump;//
	rint durJump;
	rint durBjump;
	rint durScan;
	rint durFarscan;//
	rint durFarscanPerField;//
	rint durSet;
	rint durAdd;
	rint durSub;
	rint durMul;//
	rint durDiv;//
	rint durMod;//
	rint durMin;//
	rint durMax;//
	rint durTrans;
	rint durTransPerInstr;
	rint durRtrans;//
	rint durRtransPerInstr;//
	rint durComp;
	rint durNcomp;//
	rint durGcomp;//
	rint durLcomp;//
	rint durRandom;//
	rint durCreate;
	rint durCreatePerBank;
	rint durCreateMulMobile;
	rint durCreateAddMobile;//
	rint durCreateAdvISet;
	rint durCreateSuperISet;

	rint durBreak;//
	rint durInit;//
	rint durSeize;//
	rint durResume;//
	rint durQuit;//

	rint durRemote;

	/// Read the global variables (the option set) from a RCO file.
	/// If the name is not absolute, the RCO file will be searched in a few places: 
	///    * resources
	///    * current folder
	///    * executable folder
	///    * extra_data_dir folder ... 
	bool getGlobals(const lrt::String& filename);

	/// Creates a new Globals object. Errors will be reported using the given ErrorHandler.
	Globals(const ErrorHandler* errHandler) : errHandler(errHandler) {}
	~Globals() {}

private:
	const ErrorHandler* errHandler;

	// Fetches a rint from an ini file section
	rint getRint( lrt::IniSection& sec, const char* name, rint def = -1, rint min = MIN_RINT, rint max = MAX_RINT);

	// Fetches an int from an ini file section
	int getInt( lrt::IniSection& sec, const char* name, int def = -1, int min = lrt::Math::MIN_INT, int max = lrt::Math::MAX_INT);
};



} // namespace

#endif
